@@ -22,30 +22,6 @@ import six
 import aodh
 
 
-def dict_to_keyval(value, key_base=None):
-    """Expand a given dict to its corresponding key-value pairs.
-
-    Generated keys are fully qualified, delimited using dot notation.
-    ie. key = 'key.child_key.grandchild_key[0]'
-    """
-    val_iter, key_func = None, None
-    if isinstance(value, dict):
-        val_iter = six.iteritems(value)
-        key_func = lambda k: key_base + '.' + k if key_base else k
-    elif isinstance(value, (tuple, list)):
-        val_iter = enumerate(value)
-        key_func = lambda k: key_base + '[%d]' % k
-
-    if val_iter:
-        for k, v in val_iter:
-            key_gen = key_func(k)
-            if isinstance(v, dict) or isinstance(v, (tuple, list)):
-                for key_gen, v in dict_to_keyval(v, key_gen):
-                    yield key_gen, v
-            else:
-                yield key_gen, v
-
-
 def update_nested(original_dict, updates):
     """Updates the leaf nodes in a nest dict.
 
@@ -83,6 +59,9 @@ class Model(object):
     def __eq__(self, other):
         return self.as_dict() == other.as_dict()
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     @classmethod
     def get_field_names(cls):
         fields = inspect.getargspec(cls.__init__)[0]
@@ -114,7 +93,8 @@ class Connection(object):
     @staticmethod
     def get_alarms(name=None, user=None, state=None, meter=None,
                    project=None, enabled=None, alarm_id=None,
-                   alarm_type=None, severity=None, exclude=None):
+                   alarm_type=None, severity=None, exclude=None,
+                   pagination=None):
         """Yields a lists of alarms that match filters.
 
         :param name: Optional name for alarm.
@@ -127,6 +107,7 @@ class Connection(object):
         :param alarm_type: Optional alarm type.
         :param severity: Optional alarm severity.
         :param exclude: Optional dict for inequality constraint.
+        :param pagination: Pagination parameters.
         """
         raise aodh.NotImplementedError('Alarms not implemented')
 
@@ -153,7 +134,7 @@ class Connection(object):
                           user=None, project=None, alarm_type=None,
                           severity=None, start_timestamp=None,
                           start_timestamp_op=None, end_timestamp=None,
-                          end_timestamp_op=None):
+                          end_timestamp_op=None, pagination=None):
         """Yields list of AlarmChanges describing alarm history
 
         Changes are always sorted in reverse order of occurrence, given
@@ -177,6 +158,7 @@ class Connection(object):
         :param start_timestamp_op: Optional timestamp start range operation
         :param end_timestamp: Optional modified timestamp end range
         :param end_timestamp_op: Optional timestamp end range operation
+        :param pagination: Pagination parameters.
         """
         raise aodh.NotImplementedError('Alarm history not implemented')
 
